@@ -316,10 +316,13 @@ define([
             let code = new com_String();
             let replaceDict = {'${model}': model};
 
+            // If import code is available, generate its code in front of code
             if (this.state.optionConfig.import != undefined) {
                 code.appendLine(this.state.optionConfig.import);
                 code.appendLine();
             }
+            
+            // Auto-generate model info code
             let modelCode = com_generator.vp_codeGenerator(this, this.state.optionConfig, this.state);
             if (modelCode) {
                 Object.keys(replaceDict).forEach(key => {
@@ -327,11 +330,16 @@ define([
                 });
                 code.append(modelCode);
     
-                let allocateIdx = modelCode.indexOf(' = ');
-                if (allocateIdx >= 0) {
-                    let allocateCode = modelCode.substr(0, allocateIdx);
-                    code.appendLine();
-                    code.append(allocateCode);
+                // Exception for re-generating allocate variables
+                if (!modelCode.includes('plt.show()')) {
+                    // Find allocate variable
+                    let allocateIdx = modelCode.indexOf(' = ');
+                    if (allocateIdx >= 0) {
+                        // if available, show again to display its value
+                        let allocateCode = modelCode.substr(0, allocateIdx);
+                        code.appendLine();
+                        code.append(allocateCode);
+                    }
                 }
             }
 
@@ -390,6 +398,24 @@ define([
                         { name: 'random_state', component: ['input_number'], placeholder: '123', usePair: true },
                         { name: 'importance_allocate', label: 'Allocate to', component: ['input'], placeholder: 'New variable', value: 'importances' }
                     ]
+                },
+                'plot_feature_importances': {
+                    name: 'plot_feature_importances',
+                    label: 'Plot feature importances',
+                    code: "def plot_feature_importances(model):\n\
+    n_features = len(model.feature_importances_)\n\
+    feature_names = [ 'X{}'.format(i) for i in range(n_features) ]\n\
+    plt.barh(np.arange(n_features), model.feature_importances_, align='center')\n\
+    plt.yticks(np.arange(n_features), feature_names)\n\
+    plt.xlabel('Feature importance')\n\
+    plt.ylabel('Features')\n\
+    plt.ylim(-1, n_features)\n\
+    plt.show()\n\n\
+plot_feature_importances(${model})",
+                    description: '',
+                    options: [
+
+                    ]
                 }
             }
             switch (category) {
@@ -496,6 +522,7 @@ define([
                             ]
                         },
                         'permutation_importance': defaultInfos['permutation_importance'],
+                        'plot_feature_importances': defaultInfos['plot_feature_importances'],
                         'Coefficient': {
                             name: 'coef_',
                             label: 'Coefficient',
@@ -568,7 +595,8 @@ plt.show()",
                                 { name: 'auc_featureData', label: 'Feature Data', component: ['var_select'], var_type: ['DataFrame', 'Series', 'ndarray', 'list', 'dict'], value: 'X_test' }
                             ]
                         },
-                        'permutation_importance': defaultInfos['permutation_importance']
+                        'permutation_importance': defaultInfos['permutation_importance'],
+                        'plot_feature_importances': defaultInfos['plot_feature_importances']
                     }
 
                     // use decision_function on ROC, AUC
